# distutils build script
# To install fuse-python, run 'python setup.py install'

# This setup.py based on that of shout-python (py bindings for libshout,
# part of the icecast project, http://svn.xiph.org/icecast/trunk/shout-python)

try:
    from setuptools import setup
    from setuptools.dist import Distribution
except ImportError:
    from distutils.core import setup
    from distutils.dist import Distribution
from distutils.core import Extension
import os
import sys
from pysctp import __version__

classifiers = """\
Development Status :: 4 - Beta
Intended Audience :: Developers
License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)
Operating System :: POSIX
Programming Language :: C
Programming Language :: Python
Topic :: System :: Libraries 
"""

class MyDistribution(Distribution):
    """
    Obnoxious hack to enforce the packager to generate
    the to-be-generated files
    """

    def run_command(self, command):
        if command == 'sdist':
            for f in ('Changelog'):
                 if not os.path.exists(f):
                     raise RuntimeError, 'file ' + `f` + \
                           " doesn't exist, please generate it before creating a source distribution"

        return Distribution.run_command(self, command)

cflags = "-Wall -I/usr/include/python$(PYTHON_VERSION) -fPIC"
# there must be an easier way to set up these flags!
iflags = [x[2:] for x in cflags.split() if x[0:2] == '-I']
extra_cflags = [x for x in cflags.split() if x[0:2] != '-I']
libdirs = []
libsonly = ['sctp'] 

try:
    import thread
except ImportError:
    # if our Python doesn't have thread support, we enforce
    # linking against libpthread so that libfuse's pthread
    # related symbols won't be undefined
    libsonly.append("pthread")

# include_dirs=[]
# libraries=[]
# runtime_library_dirs=[]
# extra_objects, extra_compile_args, extra_link_args
pysctpmodule = Extension('pysctp/_sctp', sources = ['_sctp.c'],
                  include_dirs = iflags,
                  extra_compile_args = extra_cflags,
                  library_dirs = libdirs,
                  libraries = libsonly)

setup (name = 'pysctp',
       description = 'Pyton bindings for SCTP protocol',
       classifiers = filter(None, classifiers.split("\n")),
       version = __version__,
       license = 'LGPL',
       platforms = ['posix'],
       url = 'http//epx.com.br/pysctp/index.php',
       author = 'Elvis Pfutzenreuter',
       author_email = 'epx@altoriopreto.com.br',
       maintainer = 'Neil Horman',
       maintainer_email = 'nhorman@tuxdriver.com',
       packages = ["pysctp"],
       ext_modules = [ pysctpmodule ],
       py_modules=[],
       distclass = MyDistribution)
